//
//  SOMAAdMobBannerReceiver.m
//  AdmobDemo
//
//  Created by Bilge Ulusoy on 01.06.12.
//  Copyright (c) 2012 Smaato Inc. All rights reserved.
//

// Updated by Shaikh Aman

#import "SOMAAdMobBannerReceiver.h"
static NSString *const customEventErrorDomain = @"com.google.CustomEvent";
@interface SOMAAdMobBannerReceiver()
@property(nonatomic, strong) SOMAAdView* somaBanner;
@end

@implementation SOMAAdMobBannerReceiver

@synthesize delegate = delegate_;

- (void)requestBannerAd:(GADAdSize)adSize
              parameter:(NSString *)serverParameter
                  label:(NSString *)serverLabel
                request:(GADCustomEventRequest *)request  {
	
	
    SOMAAdDimension dimension;
    
    // Determine Correct SOMAAdDimension for our Ad :)
    if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeBanner))) {
        dimension = SOMAAdDimensionDefault;
    } else if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeMediumRectangle))) {
        dimension = SOMAAdDimensionMedRect;
    } else if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeLeaderboard))) {
        dimension = SOMAAdDimensionLeader;
    } else if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeSkyscraper))) {
        dimension = SOMAAdDimensionSky;
    } else {
        dimension = SOMAAdDimensionDefault;
    }
    
    // Parse Adspace & Publisher ID
    NSMutableDictionary *adServerParameter = [[NSMutableDictionary alloc] init];
    NSArray *chunks = [[serverParameter lowercaseString] componentsSeparatedByString: @"&"];
    
    for (NSString *component in chunks) {
        NSArray *pair = [component componentsSeparatedByString:@"="];
        
        [adServerParameter setObject:[[pair objectAtIndex:1] stringByReplacingPercentEscapesUsingEncoding: NSMacOSRomanStringEncoding]
                        forKey:[pair objectAtIndex:0]]; 
    }
    
    // Create a SOMABannerView and apply adspace & publisher settings
    if (self.somaBanner == nil) {		
        self.somaBanner = [[SOMAAdView alloc] init];
		CGRect rect = CGRectZero;
		rect.size = CGSizeFromGADAdSize(adSize);
		self.somaBanner.frame = rect;
	}
	
	[self.somaBanner adSettings].type = SOMAAdTypeAll;
//	self.somaBanner.adSettings.httpsOnly = YES;
	[self.somaBanner adSettings].dimension = dimension;
    [self.somaBanner adSettings].adSpaceId = [[adServerParameter objectForKey:@"adspace"] intValue];
    [self.somaBanner adSettings].publisherId = [[adServerParameter objectForKey:@"publisher"] intValue];

//    [self.somaBanner.adSettings setAutoReloadInterval:30];
	self.somaBanner.adSettings.autoReloadEnabled = NO;
    self.somaBanner.autoresizingMask = UIViewAutoresizingFlexibleLeftMargin | UIViewAutoresizingFlexibleRightMargin;
	self.somaBanner.delegate  =self;
	[self.somaBanner load];
	
//    [self.somaBanner asyncLoadNewBannerWithCompletionHandler:^(id<SOMAReceivedBanner> receivedBanner
//														   , NSError *error) {
//		if (error == nil) {
//			[blockSelf performSelectorOnMainThread:@selector(adViewDidReceiveAd:)
//								   withObject:blockSelf.somaBanner
//								waitUntilDone:YES];
//		} else {
//			[blockSelf.delegate customEventBanner:self didFailAd:error];
//		}
//	}];
	
	adServerParameter = nil;
}

#pragma mark - SOMABannerViewDelegate
- (UIViewController*)somaRootViewController{
	return nil;
}

- (void)somaAdViewWillLoadAd:(SOMAAdView *)adview{
}

- (void)somaAdViewDidLoadAd:(SOMAAdView *)adview{
//	UIView* aview = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 320, 50)];
//	aview.backgroundColor = [UIColor whiteColor];
	[self.delegate customEventBanner:self didReceiveAd:adview];
}

- (void)somaAdView:(SOMAAdView *)adview didFailToReceiveAdWithError:(NSError *)error{
	error = [NSError errorWithDomain:customEventErrorDomain
										 code:error.code
									 userInfo:nil];
	[self.delegate customEventBanner:self didFailAd:error];
}

- (BOOL)somaAdViewShouldEnterFullscreen:(SOMAAdView *)adview{
	[self.delegate customEventBannerWillPresentModal:self];
	return YES;
}

- (void)somaAdViewDidExitFullscreen:(SOMAAdView *)adview{
	[self.delegate customEventBannerDidDismissModal:self];
}

- (void)dealloc {
	NSLog(@"Deallocated!!");
}

@end
